# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'xulpymoney/ui/frmProductReport.ui'
#
# Created by: PyQt5 UI code generator 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_frmProductReport(object):
    def setupUi(self, frmProductReport):
        frmProductReport.setObjectName("frmProductReport")
        frmProductReport.setWindowModality(QtCore.Qt.WindowModal)
        frmProductReport.resize(1052, 974)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/xulpmoney/dinero.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        frmProductReport.setWindowIcon(icon)
        frmProductReport.setModal(True)
        self.horizontalLayout_22 = QtWidgets.QHBoxLayout(frmProductReport)
        self.horizontalLayout_22.setObjectName("horizontalLayout_22")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.lblInvestment = QtWidgets.QLabel(frmProductReport)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.lblInvestment.setFont(font)
        self.lblInvestment.setStyleSheet("color: rgb(0, 192, 0);")
        self.lblInvestment.setText("")
        self.lblInvestment.setAlignment(QtCore.Qt.AlignCenter)
        self.lblInvestment.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextSelectableByMouse)
        self.lblInvestment.setObjectName("lblInvestment")
        self.horizontalLayout_8.addWidget(self.lblInvestment)
        self.verticalLayout.addLayout(self.horizontalLayout_8)
        self.tab = QtWidgets.QTabWidget(frmProductReport)
        self.tab.setTabPosition(QtWidgets.QTabWidget.West)
        self.tab.setObjectName("tab")
        self.tabInformacion = QtWidgets.QWidget()
        self.tabInformacion.setObjectName("tabInformacion")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.tabInformacion)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.horizontalLayout_39 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_39.setObjectName("horizontalLayout_39")
        self.scrollArea = QtWidgets.QScrollArea(self.tabInformacion)
        self.scrollArea.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName("scrollArea")
        self.scrollAreaWidgetContents = QtWidgets.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 983, 901))
        self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
        self.horizontalLayout_31 = QtWidgets.QHBoxLayout(self.scrollAreaWidgetContents)
        self.horizontalLayout_31.setObjectName("horizontalLayout_31")
        self.grpInformation = QtWidgets.QGroupBox(self.scrollAreaWidgetContents)
        self.grpInformation.setObjectName("grpInformation")
        self.horizontalLayout_26 = QtWidgets.QHBoxLayout(self.grpInformation)
        self.horizontalLayout_26.setObjectName("horizontalLayout_26")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.label = QtWidgets.QLabel(self.grpInformation)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label.sizePolicy().hasHeightForWidth())
        self.label.setSizePolicy(sizePolicy)
        self.label.setMinimumSize(QtCore.QSize(230, 0))
        self.label.setObjectName("label")
        self.horizontalLayout_10.addWidget(self.label)
        self.txtName = QtWidgets.QLineEdit(self.grpInformation)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtName.sizePolicy().hasHeightForWidth())
        self.txtName.setSizePolicy(sizePolicy)
        self.txtName.setMinimumSize(QtCore.QSize(330, 0))
        self.txtName.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtName.setObjectName("txtName")
        self.horizontalLayout_10.addWidget(self.txtName)
        self.verticalLayout_2.addLayout(self.horizontalLayout_10)
        self.horizontalLayout_21 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_21.setObjectName("horizontalLayout_21")
        self.label_10 = QtWidgets.QLabel(self.grpInformation)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_10.sizePolicy().hasHeightForWidth())
        self.label_10.setSizePolicy(sizePolicy)
        self.label_10.setMinimumSize(QtCore.QSize(230, 0))
        self.label_10.setObjectName("label_10")
        self.horizontalLayout_21.addWidget(self.label_10)
        self.txtISIN = QtWidgets.QLineEdit(self.grpInformation)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtISIN.sizePolicy().hasHeightForWidth())
        self.txtISIN.setSizePolicy(sizePolicy)
        self.txtISIN.setMinimumSize(QtCore.QSize(230, 0))
        self.txtISIN.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtISIN.setObjectName("txtISIN")
        self.horizontalLayout_21.addWidget(self.txtISIN)
        self.verticalLayout_2.addLayout(self.horizontalLayout_21)
        self.horizontalLayout_15 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_15.setObjectName("horizontalLayout_15")
        self.label_9 = QtWidgets.QLabel(self.grpInformation)
        self.label_9.setObjectName("label_9")
        self.horizontalLayout_15.addWidget(self.label_9)
        self.cmbCurrency = QtWidgets.QComboBox(self.grpInformation)
        self.cmbCurrency.setObjectName("cmbCurrency")
        self.horizontalLayout_15.addWidget(self.cmbCurrency)
        self.verticalLayout_2.addLayout(self.horizontalLayout_15)
        self.horizontalLayout_23 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_23.setObjectName("horizontalLayout_23")
        self.label_12 = QtWidgets.QLabel(self.grpInformation)
        self.label_12.setObjectName("label_12")
        self.horizontalLayout_23.addWidget(self.label_12)
        self.cmbTipo = QtWidgets.QComboBox(self.grpInformation)
        self.cmbTipo.setObjectName("cmbTipo")
        self.horizontalLayout_23.addWidget(self.cmbTipo)
        self.verticalLayout_2.addLayout(self.horizontalLayout_23)
        self.horizontalLayout_30 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_30.setObjectName("horizontalLayout_30")
        self.label_16 = QtWidgets.QLabel(self.grpInformation)
        self.label_16.setObjectName("label_16")
        self.horizontalLayout_30.addWidget(self.label_16)
        self.cmbBolsa = QtWidgets.QComboBox(self.grpInformation)
        self.cmbBolsa.setObjectName("cmbBolsa")
        self.horizontalLayout_30.addWidget(self.cmbBolsa)
        self.verticalLayout_2.addLayout(self.horizontalLayout_30)
        self.horizontalLayout_24 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_24.setObjectName("horizontalLayout_24")
        self.label_13 = QtWidgets.QLabel(self.grpInformation)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_13.sizePolicy().hasHeightForWidth())
        self.label_13.setSizePolicy(sizePolicy)
        self.label_13.setMinimumSize(QtCore.QSize(230, 0))
        self.label_13.setObjectName("label_13")
        self.horizontalLayout_24.addWidget(self.label_13)
        self.cmbAgrupations = QtWidgets.QComboBox(self.grpInformation)
        self.cmbAgrupations.setObjectName("cmbAgrupations")
        self.horizontalLayout_24.addWidget(self.cmbAgrupations)
        self.cmdAgrupations = QtWidgets.QToolButton(self.grpInformation)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/xulpymoney/search.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.cmdAgrupations.setIcon(icon1)
        self.cmdAgrupations.setObjectName("cmdAgrupations")
        self.horizontalLayout_24.addWidget(self.cmdAgrupations)
        self.verticalLayout_2.addLayout(self.horizontalLayout_24)
        self.horizontalLayout_14 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_14.setObjectName("horizontalLayout_14")
        self.label_3 = QtWidgets.QLabel(self.grpInformation)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_14.addWidget(self.label_3)
        self.txtWeb = QtWidgets.QLineEdit(self.grpInformation)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtWeb.sizePolicy().hasHeightForWidth())
        self.txtWeb.setSizePolicy(sizePolicy)
        self.txtWeb.setMinimumSize(QtCore.QSize(230, 0))
        self.txtWeb.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtWeb.setObjectName("txtWeb")
        self.horizontalLayout_14.addWidget(self.txtWeb)
        self.verticalLayout_2.addLayout(self.horizontalLayout_14)
        self.horizontalLayout_17 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_17.setObjectName("horizontalLayout_17")
        self.label_4 = QtWidgets.QLabel(self.grpInformation)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_17.addWidget(self.label_4)
        self.txtAddress = QtWidgets.QLineEdit(self.grpInformation)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtAddress.sizePolicy().hasHeightForWidth())
        self.txtAddress.setSizePolicy(sizePolicy)
        self.txtAddress.setMinimumSize(QtCore.QSize(230, 0))
        self.txtAddress.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtAddress.setObjectName("txtAddress")
        self.horizontalLayout_17.addWidget(self.txtAddress)
        self.verticalLayout_2.addLayout(self.horizontalLayout_17)
        self.horizontalLayout_27 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_27.setObjectName("horizontalLayout_27")
        self.lblMail = QtWidgets.QLabel(self.grpInformation)
        self.lblMail.setObjectName("lblMail")
        self.horizontalLayout_27.addWidget(self.lblMail)
        self.txtMail = QtWidgets.QLineEdit(self.grpInformation)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtMail.sizePolicy().hasHeightForWidth())
        self.txtMail.setSizePolicy(sizePolicy)
        self.txtMail.setMinimumSize(QtCore.QSize(230, 0))
        self.txtMail.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtMail.setObjectName("txtMail")
        self.horizontalLayout_27.addWidget(self.txtMail)
        self.verticalLayout_2.addLayout(self.horizontalLayout_27)
        self.horizontalLayout_28 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_28.setObjectName("horizontalLayout_28")
        self.label_14 = QtWidgets.QLabel(self.grpInformation)
        self.label_14.setObjectName("label_14")
        self.horizontalLayout_28.addWidget(self.label_14)
        self.txtTPC = QtWidgets.QLineEdit(self.grpInformation)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtTPC.sizePolicy().hasHeightForWidth())
        self.txtTPC.setSizePolicy(sizePolicy)
        self.txtTPC.setMinimumSize(QtCore.QSize(230, 0))
        self.txtTPC.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtTPC.setObjectName("txtTPC")
        self.horizontalLayout_28.addWidget(self.txtTPC)
        self.verticalLayout_2.addLayout(self.horizontalLayout_28)
        self.horizontalLayout_38 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_38.setObjectName("horizontalLayout_38")
        self.label_22 = QtWidgets.QLabel(self.grpInformation)
        self.label_22.setObjectName("label_22")
        self.horizontalLayout_38.addWidget(self.label_22)
        self.cmbPCI = QtWidgets.QComboBox(self.grpInformation)
        self.cmbPCI.setObjectName("cmbPCI")
        self.horizontalLayout_38.addWidget(self.cmbPCI)
        self.verticalLayout_2.addLayout(self.horizontalLayout_38)
        self.horizontalLayout_18 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_18.setObjectName("horizontalLayout_18")
        self.label_5 = QtWidgets.QLabel(self.grpInformation)
        self.label_5.setObjectName("label_5")
        self.horizontalLayout_18.addWidget(self.label_5)
        self.txtPhone = QtWidgets.QLineEdit(self.grpInformation)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtPhone.sizePolicy().hasHeightForWidth())
        self.txtPhone.setSizePolicy(sizePolicy)
        self.txtPhone.setMinimumSize(QtCore.QSize(230, 0))
        self.txtPhone.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtPhone.setObjectName("txtPhone")
        self.horizontalLayout_18.addWidget(self.txtPhone)
        self.verticalLayout_2.addLayout(self.horizontalLayout_18)
        self.horizontalLayout_29 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_29.setObjectName("horizontalLayout_29")
        self.label_15 = QtWidgets.QLabel(self.grpInformation)
        self.label_15.setObjectName("label_15")
        self.horizontalLayout_29.addWidget(self.label_15)
        self.cmbApalancado = QtWidgets.QComboBox(self.grpInformation)
        self.cmbApalancado.setObjectName("cmbApalancado")
        self.horizontalLayout_29.addWidget(self.cmbApalancado)
        self.verticalLayout_2.addLayout(self.horizontalLayout_29)
        self.horizontalLayout_42 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_42.setObjectName("horizontalLayout_42")
        self.label_11 = QtWidgets.QLabel(self.grpInformation)
        self.label_11.setMinimumSize(QtCore.QSize(280, 0))
        self.label_11.setObjectName("label_11")
        self.horizontalLayout_42.addWidget(self.label_11)
        self.tblTickers = QtWidgets.QTableWidget(self.grpInformation)
        self.tblTickers.setMinimumSize(QtCore.QSize(230, 0))
        self.tblTickers.setAlternatingRowColors(True)
        self.tblTickers.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.tblTickers.setObjectName("tblTickers")
        self.tblTickers.setColumnCount(1)
        self.tblTickers.setRowCount(4)
        item = QtWidgets.QTableWidgetItem()
        self.tblTickers.setVerticalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTickers.setVerticalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTickers.setVerticalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTickers.setVerticalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTickers.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/xulpymoney/eye_red.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        item.setIcon(icon2)
        self.tblTickers.setItem(0, 0, item)
        item = QtWidgets.QTableWidgetItem()
        item.setIcon(icon2)
        self.tblTickers.setItem(1, 0, item)
        item = QtWidgets.QTableWidgetItem()
        item.setIcon(icon2)
        self.tblTickers.setItem(2, 0, item)
        item = QtWidgets.QTableWidgetItem()
        item.setIcon(icon2)
        self.tblTickers.setItem(3, 0, item)
        self.tblTickers.horizontalHeader().setStretchLastSection(True)
        self.tblTickers.verticalHeader().setVisible(True)
        self.horizontalLayout_42.addWidget(self.tblTickers)
        self.verticalLayout_2.addLayout(self.horizontalLayout_42)
        self.horizontalLayout_36 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_36.setObjectName("horizontalLayout_36")
        self.label_21 = QtWidgets.QLabel(self.grpInformation)
        self.label_21.setObjectName("label_21")
        self.horizontalLayout_36.addWidget(self.label_21)
        self.txtComentario = QtWidgets.QLineEdit(self.grpInformation)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtComentario.sizePolicy().hasHeightForWidth())
        self.txtComentario.setSizePolicy(sizePolicy)
        self.txtComentario.setMinimumSize(QtCore.QSize(230, 0))
        self.txtComentario.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtComentario.setObjectName("txtComentario")
        self.horizontalLayout_36.addWidget(self.txtComentario)
        self.verticalLayout_2.addLayout(self.horizontalLayout_36)
        self.chkHL = QtWidgets.QCheckBox(self.grpInformation)
        self.chkHL.setObjectName("chkHL")
        self.verticalLayout_2.addWidget(self.chkHL)
        self.horizontalLayout_33 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_33.setObjectName("horizontalLayout_33")
        self.chkObsolete = QtWidgets.QCheckBox(self.grpInformation)
        self.chkObsolete.setObjectName("chkObsolete")
        self.horizontalLayout_33.addWidget(self.chkObsolete)
        self.verticalLayout_2.addLayout(self.horizontalLayout_33)
        self.lblAutoupdate = QtWidgets.QLabel(self.grpInformation)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.lblAutoupdate.setFont(font)
        self.lblAutoupdate.setText("")
        self.lblAutoupdate.setObjectName("lblAutoupdate")
        self.verticalLayout_2.addWidget(self.lblAutoupdate)
        self.cmdSave = QtWidgets.QPushButton(self.grpInformation)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/xulpymoney/save.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.cmdSave.setIcon(icon3)
        self.cmdSave.setObjectName("cmdSave")
        self.verticalLayout_2.addWidget(self.cmdSave)
        self.horizontalLayout_26.addLayout(self.verticalLayout_2)
        self.horizontalLayout_31.addWidget(self.grpInformation)
        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
        self.horizontalLayout_39.addWidget(self.scrollArea)
        self.verticalLayout_5.addLayout(self.horizontalLayout_39)
        self.tab.addTab(self.tabInformacion, "")
        self.tabGraficos = QtWidgets.QWidget()
        self.tabGraficos.setObjectName("tabGraficos")
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout(self.tabGraficos)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.tabGraphics = QtWidgets.QTabWidget(self.tabGraficos)
        self.tabGraphics.setObjectName("tabGraphics")
        self.tabGraphicsIntraday = QtWidgets.QWidget()
        self.tabGraphicsIntraday.setObjectName("tabGraphicsIntraday")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.tabGraphicsIntraday)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.splitter = QtWidgets.QSplitter(self.tabGraphicsIntraday)
        self.splitter.setOrientation(QtCore.Qt.Horizontal)
        self.splitter.setObjectName("splitter")
        self.groupBox_3 = QtWidgets.QGroupBox(self.splitter)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_3.sizePolicy().hasHeightForWidth())
        self.groupBox_3.setSizePolicy(sizePolicy)
        self.groupBox_3.setMaximumSize(QtCore.QSize(400, 16777215))
        self.groupBox_3.setObjectName("groupBox_3")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.groupBox_3)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_7.addItem(spacerItem)
        self.calendar = QtWidgets.QCalendarWidget(self.groupBox_3)
        self.calendar.setMaximumSize(QtCore.QSize(300, 200))
        self.calendar.setFirstDayOfWeek(QtCore.Qt.Monday)
        self.calendar.setHorizontalHeaderFormat(QtWidgets.QCalendarWidget.SingleLetterDayNames)
        self.calendar.setVerticalHeaderFormat(QtWidgets.QCalendarWidget.NoVerticalHeader)
        self.calendar.setObjectName("calendar")
        self.horizontalLayout_7.addWidget(self.calendar)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_7.addItem(spacerItem1)
        self.verticalLayout_3.addLayout(self.horizontalLayout_7)
        self.tblIntradia = myQTableWidget(self.groupBox_3)
        self.tblIntradia.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tblIntradia.setAlternatingRowColors(True)
        self.tblIntradia.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tblIntradia.setObjectName("tblIntradia")
        self.tblIntradia.setColumnCount(0)
        self.tblIntradia.setRowCount(0)
        self.tblIntradia.verticalHeader().setVisible(False)
        self.verticalLayout_3.addWidget(self.tblIntradia)
        self.lblIntradayVariance = QtWidgets.QLabel(self.groupBox_3)
        self.lblIntradayVariance.setText("")
        self.lblIntradayVariance.setObjectName("lblIntradayVariance")
        self.verticalLayout_3.addWidget(self.lblIntradayVariance)
        self.verticalLayout_6.addLayout(self.verticalLayout_3)
        self.grpGraphIntraday = QtWidgets.QGroupBox(self.splitter)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.grpGraphIntraday.sizePolicy().hasHeightForWidth())
        self.grpGraphIntraday.setSizePolicy(sizePolicy)
        self.grpGraphIntraday.setObjectName("grpGraphIntraday")
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout(self.grpGraphIntraday)
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.layIntraday = QtWidgets.QVBoxLayout()
        self.layIntraday.setObjectName("layIntraday")
        self.horizontalLayout_11.addLayout(self.layIntraday)
        self.horizontalLayout.addWidget(self.splitter)
        self.tabGraphics.addTab(self.tabGraphicsIntraday, "")
        self.tabGraphicsHistorical = QtWidgets.QWidget()
        self.tabGraphicsHistorical.setObjectName("tabGraphicsHistorical")
        self.horizontalLayout_34 = QtWidgets.QHBoxLayout(self.tabGraphicsHistorical)
        self.horizontalLayout_34.setObjectName("horizontalLayout_34")
        self.groupBox_2 = QtWidgets.QGroupBox(self.tabGraphicsHistorical)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_2.sizePolicy().hasHeightForWidth())
        self.groupBox_2.setSizePolicy(sizePolicy)
        self.groupBox_2.setObjectName("groupBox_2")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.groupBox_2)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.layHistorical = QtWidgets.QVBoxLayout()
        self.layHistorical.setObjectName("layHistorical")
        self.verticalLayout_10.addLayout(self.layHistorical)
        self.horizontalLayout_34.addWidget(self.groupBox_2)
        self.tabGraphics.addTab(self.tabGraphicsHistorical, "")
        self.horizontalLayout_6.addWidget(self.tabGraphics)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/xulpymoney/pie.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.tab.addTab(self.tabGraficos, icon4, "")
        self.tabQuotes = QtWidgets.QWidget()
        self.tabQuotes.setObjectName("tabQuotes")
        self.horizontalLayout_37 = QtWidgets.QHBoxLayout(self.tabQuotes)
        self.horizontalLayout_37.setObjectName("horizontalLayout_37")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout()
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.grpHistoricos = QtWidgets.QGroupBox(self.tabQuotes)
        self.grpHistoricos.setObjectName("grpHistoricos")
        self.horizontalLayout_19 = QtWidgets.QHBoxLayout(self.grpHistoricos)
        self.horizontalLayout_19.setObjectName("horizontalLayout_19")
        self.tblTPC = myQTableWidget(self.grpHistoricos)
        self.tblTPC.setObjectName("tblTPC")
        self.tblTPC.setColumnCount(5)
        self.tblTPC.setRowCount(10)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setVerticalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setVerticalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setVerticalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setVerticalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setVerticalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setVerticalHeaderItem(5, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setVerticalHeaderItem(6, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setVerticalHeaderItem(7, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setVerticalHeaderItem(8, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setVerticalHeaderItem(9, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        font = QtGui.QFont()
        font.setStrikeOut(False)
        item.setFont(font)
        self.tblTPC.setItem(0, 0, item)
        item = QtWidgets.QTableWidgetItem()
        brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
        brush.setStyle(QtCore.Qt.BDiagPattern)
        item.setBackground(brush)
        self.tblTPC.setItem(0, 2, item)
        item = QtWidgets.QTableWidgetItem()
        brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
        brush.setStyle(QtCore.Qt.BDiagPattern)
        item.setBackground(brush)
        self.tblTPC.setItem(0, 3, item)
        item = QtWidgets.QTableWidgetItem()
        brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
        brush.setStyle(QtCore.Qt.BDiagPattern)
        item.setBackground(brush)
        self.tblTPC.setItem(0, 4, item)
        self.horizontalLayout_19.addWidget(self.tblTPC)
        self.verticalLayout_7.addWidget(self.grpHistoricos)
        self.horizontalLayout_16 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_16.setObjectName("horizontalLayout_16")
        self.cmdPurge = QtWidgets.QPushButton(self.tabQuotes)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/xulpymoney/button_cancel.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.cmdPurge.setIcon(icon5)
        self.cmdPurge.setObjectName("cmdPurge")
        self.horizontalLayout_16.addWidget(self.cmdPurge)
        self.cmdSplitManual = QtWidgets.QPushButton(self.tabQuotes)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/xulpymoney/history2.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.cmdSplitManual.setIcon(icon6)
        self.cmdSplitManual.setObjectName("cmdSplitManual")
        self.horizontalLayout_16.addWidget(self.cmdSplitManual)
        self.verticalLayout_7.addLayout(self.horizontalLayout_16)
        self.groupBox_9 = QtWidgets.QGroupBox(self.tabQuotes)
        self.groupBox_9.setObjectName("groupBox_9")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(self.groupBox_9)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.tabHistorical = QtWidgets.QTabWidget(self.groupBox_9)
        self.tabHistorical.setElideMode(QtCore.Qt.ElideMiddle)
        self.tabHistorical.setObjectName("tabHistorical")
        self.tab_5 = QtWidgets.QWidget()
        self.tab_5.setObjectName("tab_5")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.tab_5)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.verticalLayout_12 = QtWidgets.QVBoxLayout()
        self.verticalLayout_12.setObjectName("verticalLayout_12")
        self.tblDaily = myQTableWidget(self.tab_5)
        self.tblDaily.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tblDaily.setAlternatingRowColors(True)
        self.tblDaily.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tblDaily.setObjectName("tblDaily")
        self.tblDaily.setColumnCount(6)
        self.tblDaily.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tblDaily.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblDaily.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblDaily.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblDaily.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblDaily.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblDaily.setHorizontalHeaderItem(5, item)
        self.tblDaily.verticalHeader().setVisible(False)
        self.verticalLayout_12.addWidget(self.tblDaily)
        self.label_6 = QtWidgets.QLabel(self.tab_5)
        self.label_6.setObjectName("label_6")
        self.verticalLayout_12.addWidget(self.label_6)
        self.horizontalLayout_3.addLayout(self.verticalLayout_12)
        self.tabHistorical.addTab(self.tab_5, "")
        self.tab_14 = QtWidgets.QWidget()
        self.tab_14.setObjectName("tab_14")
        self.horizontalLayout_32 = QtWidgets.QHBoxLayout(self.tab_14)
        self.horizontalLayout_32.setObjectName("horizontalLayout_32")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout()
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.tblWeekly = myQTableWidget(self.tab_14)
        self.tblWeekly.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tblWeekly.setAlternatingRowColors(True)
        self.tblWeekly.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tblWeekly.setObjectName("tblWeekly")
        self.tblWeekly.setColumnCount(6)
        self.tblWeekly.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tblWeekly.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblWeekly.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblWeekly.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblWeekly.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblWeekly.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblWeekly.setHorizontalHeaderItem(5, item)
        self.tblWeekly.verticalHeader().setVisible(False)
        self.verticalLayout_4.addWidget(self.tblWeekly)
        self.label_8 = QtWidgets.QLabel(self.tab_14)
        self.label_8.setObjectName("label_8")
        self.verticalLayout_4.addWidget(self.label_8)
        self.horizontalLayout_32.addLayout(self.verticalLayout_4)
        self.tabHistorical.addTab(self.tab_14, "")
        self.tab_3 = QtWidgets.QWidget()
        self.tab_3.setObjectName("tab_3")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.tab_3)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.verticalLayout_13 = QtWidgets.QVBoxLayout()
        self.verticalLayout_13.setObjectName("verticalLayout_13")
        self.tblMonthly = myQTableWidget(self.tab_3)
        self.tblMonthly.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tblMonthly.setAlternatingRowColors(True)
        self.tblMonthly.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tblMonthly.setObjectName("tblMonthly")
        self.tblMonthly.setColumnCount(6)
        self.tblMonthly.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tblMonthly.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMonthly.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMonthly.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMonthly.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMonthly.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMonthly.setHorizontalHeaderItem(5, item)
        self.tblMonthly.verticalHeader().setVisible(False)
        self.verticalLayout_13.addWidget(self.tblMonthly)
        self.label_17 = QtWidgets.QLabel(self.tab_3)
        self.label_17.setObjectName("label_17")
        self.verticalLayout_13.addWidget(self.label_17)
        self.horizontalLayout_2.addLayout(self.verticalLayout_13)
        self.tabHistorical.addTab(self.tab_3, "")
        self.tab_13 = QtWidgets.QWidget()
        self.tab_13.setObjectName("tab_13")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.tab_13)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.verticalLayout_14 = QtWidgets.QVBoxLayout()
        self.verticalLayout_14.setObjectName("verticalLayout_14")
        self.tblYearly = myQTableWidget(self.tab_13)
        self.tblYearly.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tblYearly.setAlternatingRowColors(True)
        self.tblYearly.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tblYearly.setObjectName("tblYearly")
        self.tblYearly.setColumnCount(6)
        self.tblYearly.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tblYearly.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblYearly.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblYearly.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblYearly.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblYearly.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblYearly.setHorizontalHeaderItem(5, item)
        self.tblYearly.verticalHeader().setVisible(False)
        self.verticalLayout_14.addWidget(self.tblYearly)
        self.label_18 = QtWidgets.QLabel(self.tab_13)
        self.label_18.setObjectName("label_18")
        self.verticalLayout_14.addWidget(self.label_18)
        self.horizontalLayout_4.addLayout(self.verticalLayout_14)
        self.tabHistorical.addTab(self.tab_13, "")
        self.tab_6 = QtWidgets.QWidget()
        self.tab_6.setObjectName("tab_6")
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout(self.tab_6)
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.verticalLayout_15 = QtWidgets.QVBoxLayout()
        self.verticalLayout_15.setObjectName("verticalLayout_15")
        self.tblMensuales = myQTableWidget(self.tab_6)
        self.tblMensuales.setObjectName("tblMensuales")
        self.tblMensuales.setColumnCount(14)
        self.tblMensuales.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(5, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(6, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(7, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(8, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(9, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(10, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(11, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(12, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(13, item)
        self.tblMensuales.verticalHeader().setVisible(False)
        self.verticalLayout_15.addWidget(self.tblMensuales)
        self.label_19 = QtWidgets.QLabel(self.tab_6)
        self.label_19.setObjectName("label_19")
        self.verticalLayout_15.addWidget(self.label_19)
        self.horizontalLayout_9.addLayout(self.verticalLayout_15)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/xulpymoney/tools-wizard.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.tabHistorical.addTab(self.tab_6, icon7, "")
        self.tabSplits = QtWidgets.QWidget()
        self.tabSplits.setObjectName("tabSplits")
        self.horizontalLayout_45 = QtWidgets.QHBoxLayout(self.tabSplits)
        self.horizontalLayout_45.setObjectName("horizontalLayout_45")
        self.tblSplits = myQTableWidget(self.tabSplits)
        self.tblSplits.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tblSplits.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.tblSplits.setAlternatingRowColors(True)
        self.tblSplits.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.tblSplits.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tblSplits.setObjectName("tblSplits")
        self.tblSplits.setColumnCount(0)
        self.tblSplits.setRowCount(0)
        self.tblSplits.verticalHeader().setVisible(False)
        self.horizontalLayout_45.addWidget(self.tblSplits)
        self.tabHistorical.addTab(self.tabSplits, "")
        self.horizontalLayout_5.addWidget(self.tabHistorical)
        self.verticalLayout_7.addWidget(self.groupBox_9)
        self.horizontalLayout_37.addLayout(self.verticalLayout_7)
        self.tab.addTab(self.tabQuotes, "")
        self.tabOther = QtWidgets.QWidget()
        self.tabOther.setObjectName("tabOther")
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout(self.tabOther)
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        self.tabEstimaciones = QtWidgets.QTabWidget(self.tabOther)
        self.tabEstimaciones.setObjectName("tabEstimaciones")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.horizontalLayout_40 = QtWidgets.QHBoxLayout(self.tab_2)
        self.horizontalLayout_40.setObjectName("horizontalLayout_40")
        self.tblDPSPaid = myQTableWidget(self.tab_2)
        self.tblDPSPaid.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tblDPSPaid.setAlternatingRowColors(True)
        self.tblDPSPaid.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tblDPSPaid.setObjectName("tblDPSPaid")
        self.tblDPSPaid.setColumnCount(0)
        self.tblDPSPaid.setRowCount(0)
        self.tblDPSPaid.verticalHeader().setVisible(False)
        self.horizontalLayout_40.addWidget(self.tblDPSPaid)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/xulpymoney/coins.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.tabEstimaciones.addTab(self.tab_2, icon8, "")
        self.tab_8 = QtWidgets.QWidget()
        self.tab_8.setObjectName("tab_8")
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout(self.tab_8)
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.tblDividendsEstimations = myQTableWidget(self.tab_8)
        self.tblDividendsEstimations.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tblDividendsEstimations.setAlternatingRowColors(True)
        self.tblDividendsEstimations.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tblDividendsEstimations.setObjectName("tblDividendsEstimations")
        self.tblDividendsEstimations.setColumnCount(6)
        self.tblDividendsEstimations.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tblDividendsEstimations.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblDividendsEstimations.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblDividendsEstimations.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblDividendsEstimations.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblDividendsEstimations.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblDividendsEstimations.setHorizontalHeaderItem(5, item)
        self.tblDividendsEstimations.verticalHeader().setVisible(False)
        self.horizontalLayout_13.addWidget(self.tblDividendsEstimations)
        self.tabEstimaciones.addTab(self.tab_8, icon8, "")
        self.tab_9 = QtWidgets.QWidget()
        self.tab_9.setObjectName("tab_9")
        self.horizontalLayout_20 = QtWidgets.QHBoxLayout(self.tab_9)
        self.horizontalLayout_20.setObjectName("horizontalLayout_20")
        self.tblEPS = myQTableWidget(self.tab_9)
        self.tblEPS.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tblEPS.setAlternatingRowColors(True)
        self.tblEPS.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tblEPS.setObjectName("tblEPS")
        self.tblEPS.setColumnCount(6)
        self.tblEPS.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tblEPS.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblEPS.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblEPS.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblEPS.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblEPS.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblEPS.setHorizontalHeaderItem(5, item)
        self.tblEPS.verticalHeader().setVisible(False)
        self.horizontalLayout_20.addWidget(self.tblEPS)
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(":/xulpymoney/star.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.tabEstimaciones.addTab(self.tab_9, icon9, "")
        self.horizontalLayout_12.addWidget(self.tabEstimaciones)
        self.tab.addTab(self.tabOther, "")
        self.verticalLayout.addWidget(self.tab)
        self.horizontalLayout_22.addLayout(self.verticalLayout)
        self.actionQuoteNew = QtWidgets.QAction(frmProductReport)
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(":/xulpymoney/add.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionQuoteNew.setIcon(icon10)
        self.actionQuoteNew.setObjectName("actionQuoteNew")
        self.actionQuoteDelete = QtWidgets.QAction(frmProductReport)
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap(":/xulpymoney/list-remove.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionQuoteDelete.setIcon(icon11)
        self.actionQuoteDelete.setObjectName("actionQuoteDelete")
        self.actionEstimationDPSNew = QtWidgets.QAction(frmProductReport)
        self.actionEstimationDPSNew.setIcon(icon10)
        self.actionEstimationDPSNew.setObjectName("actionEstimationDPSNew")
        self.actionEstimationDPSDelete = QtWidgets.QAction(frmProductReport)
        self.actionEstimationDPSDelete.setIcon(icon11)
        self.actionEstimationDPSDelete.setObjectName("actionEstimationDPSDelete")
        self.actionPurgeDay = QtWidgets.QAction(frmProductReport)
        self.actionPurgeDay.setIcon(icon7)
        self.actionPurgeDay.setObjectName("actionPurgeDay")
        self.actionQuoteEdit = QtWidgets.QAction(frmProductReport)
        icon12 = QtGui.QIcon()
        icon12.addPixmap(QtGui.QPixmap(":/xulpymoney/editar.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionQuoteEdit.setIcon(icon12)
        self.actionQuoteEdit.setObjectName("actionQuoteEdit")
        self.actionEstimationEPSNew = QtWidgets.QAction(frmProductReport)
        self.actionEstimationEPSNew.setIcon(icon10)
        self.actionEstimationEPSNew.setObjectName("actionEstimationEPSNew")
        self.actionEstimationEPSDelete = QtWidgets.QAction(frmProductReport)
        self.actionEstimationEPSDelete.setIcon(icon11)
        self.actionEstimationEPSDelete.setObjectName("actionEstimationEPSDelete")
        self.actionDPSNew = QtWidgets.QAction(frmProductReport)
        self.actionDPSNew.setIcon(icon10)
        self.actionDPSNew.setObjectName("actionDPSNew")
        self.actionDPSDelete = QtWidgets.QAction(frmProductReport)
        self.actionDPSDelete.setIcon(icon11)
        self.actionDPSDelete.setObjectName("actionDPSDelete")
        self.actionDividendXuNew = QtWidgets.QAction(frmProductReport)
        self.actionDividendXuNew.setIcon(icon8)
        self.actionDividendXuNew.setObjectName("actionDividendXuNew")
        self.actionQuoteDeleteDays = QtWidgets.QAction(frmProductReport)
        self.actionQuoteDeleteDays.setIcon(icon11)
        self.actionQuoteDeleteDays.setObjectName("actionQuoteDeleteDays")
        self.actionQuoteDeleteMonths = QtWidgets.QAction(frmProductReport)
        self.actionQuoteDeleteMonths.setIcon(icon11)
        self.actionQuoteDeleteMonths.setObjectName("actionQuoteDeleteMonths")
        self.actionQuoteDeleteYears = QtWidgets.QAction(frmProductReport)
        self.actionQuoteDeleteYears.setIcon(icon11)
        self.actionQuoteDeleteYears.setObjectName("actionQuoteDeleteYears")
        self.actionQuoteImport = QtWidgets.QAction(frmProductReport)
        icon13 = QtGui.QIcon()
        icon13.addPixmap(QtGui.QPixmap(":/xulpymoney/libreoffice_calc.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionQuoteImport.setIcon(icon13)
        self.actionQuoteImport.setObjectName("actionQuoteImport")
        self.actionSplitNew = QtWidgets.QAction(frmProductReport)
        self.actionSplitNew.setIcon(icon10)
        self.actionSplitNew.setObjectName("actionSplitNew")
        self.actionSplitRemove = QtWidgets.QAction(frmProductReport)
        self.actionSplitRemove.setIcon(icon11)
        self.actionSplitRemove.setObjectName("actionSplitRemove")
        self.actionSplitEdit = QtWidgets.QAction(frmProductReport)
        self.actionSplitEdit.setIcon(icon12)
        self.actionSplitEdit.setObjectName("actionSplitEdit")
        self.actionDPSImport = QtWidgets.QAction(frmProductReport)
        self.actionDPSImport.setIcon(icon13)
        self.actionDPSImport.setObjectName("actionDPSImport")
        self.actionQuoteExport = QtWidgets.QAction(frmProductReport)
        self.actionQuoteExport.setIcon(icon13)
        self.actionQuoteExport.setObjectName("actionQuoteExport")

        self.retranslateUi(frmProductReport)
        self.tab.setCurrentIndex(0)
        self.tabGraphics.setCurrentIndex(0)
        self.tabHistorical.setCurrentIndex(4)
        self.tabEstimaciones.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(frmProductReport)

    def retranslateUi(self, frmProductReport):
        _translate = QtCore.QCoreApplication.translate
        frmProductReport.setWindowTitle(_translate("frmProductReport", "Product report"))
        self.grpInformation.setTitle(_translate("frmProductReport", "Information"))
        self.label.setText(_translate("frmProductReport", "Product name"))
        self.label_10.setText(_translate("frmProductReport", "ISIN code"))
        self.label_9.setText(_translate("frmProductReport", "Currency"))
        self.label_12.setText(_translate("frmProductReport", "Product type"))
        self.label_16.setText(_translate("frmProductReport", "Stock exchange"))
        self.label_13.setText(_translate("frmProductReport", "Agrupations"))
        self.label_3.setText(_translate("frmProductReport", "Web page"))
        self.label_4.setText(_translate("frmProductReport", "Address"))
        self.lblMail.setText(_translate("frmProductReport", "Email"))
        self.label_14.setText(_translate("frmProductReport", "Variable percentage"))
        self.txtTPC.setText(_translate("frmProductReport", "100"))
        self.label_22.setText(_translate("frmProductReport", "Put / Call / Inline"))
        self.label_5.setText(_translate("frmProductReport", "Telephone"))
        self.label_15.setText(_translate("frmProductReport", "Leveraged"))
        self.label_11.setText(_translate("frmProductReport", "Tickers"))
        item = self.tblTickers.verticalHeaderItem(0)
        item.setText(_translate("frmProductReport", "Yahoo"))
        item = self.tblTickers.verticalHeaderItem(1)
        item.setText(_translate("frmProductReport", "Morningstar"))
        item = self.tblTickers.verticalHeaderItem(2)
        item.setText(_translate("frmProductReport", "Google"))
        item = self.tblTickers.verticalHeaderItem(3)
        item.setText(_translate("frmProductReport", "QueFondos"))
        item = self.tblTickers.horizontalHeaderItem(0)
        item.setText(_translate("frmProductReport", "Value"))
        __sortingEnabled = self.tblTickers.isSortingEnabled()
        self.tblTickers.setSortingEnabled(False)
        self.tblTickers.setSortingEnabled(__sortingEnabled)
        self.label_21.setText(_translate("frmProductReport", "Comment"))
        self.chkHL.setText(_translate("frmProductReport", "Allow short and long contracts"))
        self.chkObsolete.setText(_translate("frmProductReport", "Obsolete product"))
        self.cmdSave.setText(_translate("frmProductReport", "Update investment"))
        self.tab.setTabText(self.tab.indexOf(self.tabInformacion), _translate("frmProductReport", "Investment information"))
        self.groupBox_3.setTitle(_translate("frmProductReport", "Product prices"))
        self.grpGraphIntraday.setTitle(_translate("frmProductReport", "Daily prices graph"))
        self.tabGraphics.setTabText(self.tabGraphics.indexOf(self.tabGraphicsIntraday), _translate("frmProductReport", "Daily"))
        self.groupBox_2.setTitle(_translate("frmProductReport", "Historical prices graph"))
        self.tabGraphics.setTabText(self.tabGraphics.indexOf(self.tabGraphicsHistorical), _translate("frmProductReport", "Historical"))
        self.tab.setTabText(self.tab.indexOf(self.tabGraficos), _translate("frmProductReport", "Charts"))
        self.grpHistoricos.setTitle(_translate("frmProductReport", "Report of historic prices"))
        item = self.tblTPC.verticalHeaderItem(0)
        item.setText(_translate("frmProductReport", "Last price"))
        item = self.tblTPC.verticalHeaderItem(2)
        item.setText(_translate("frmProductReport", "Daily variation"))
        item = self.tblTPC.verticalHeaderItem(3)
        item.setText(_translate("frmProductReport", "Weekly variation"))
        item = self.tblTPC.verticalHeaderItem(4)
        item.setText(_translate("frmProductReport", "Monthly variation"))
        item = self.tblTPC.verticalHeaderItem(5)
        item.setText(_translate("frmProductReport", "Annual variation"))
        item = self.tblTPC.verticalHeaderItem(7)
        item.setText(_translate("frmProductReport", "Last 7 days variation"))
        item = self.tblTPC.verticalHeaderItem(8)
        item.setText(_translate("frmProductReport", "Last 30 days variation"))
        item = self.tblTPC.verticalHeaderItem(9)
        item.setText(_translate("frmProductReport", "Last 12 months variation"))
        item = self.tblTPC.horizontalHeaderItem(0)
        item.setText(_translate("frmProductReport", "Date"))
        item = self.tblTPC.horizontalHeaderItem(1)
        item.setText(_translate("frmProductReport", "Price"))
        item = self.tblTPC.horizontalHeaderItem(2)
        item.setText(_translate("frmProductReport", "%"))
        item = self.tblTPC.horizontalHeaderItem(3)
        item.setText(_translate("frmProductReport", "% APR"))
        item = self.tblTPC.horizontalHeaderItem(4)
        item.setText(_translate("frmProductReport", "Gains"))
        __sortingEnabled = self.tblTPC.isSortingEnabled()
        self.tblTPC.setSortingEnabled(False)
        self.tblTPC.setSortingEnabled(__sortingEnabled)
        self.cmdPurge.setToolTip(_translate("frmProductReport", "Purge investment from innecesary quotes. Leaves high, low, open and close quotes"))
        self.cmdPurge.setText(_translate("frmProductReport", "Purge investment"))
        self.cmdSplitManual.setText(_translate("frmProductReport", "Adjust Split / Contrasplit manually in prices"))
        self.groupBox_9.setTitle(_translate("frmProductReport", "Product prices"))
        item = self.tblDaily.horizontalHeaderItem(0)
        item.setText(_translate("frmProductReport", "Date"))
        item = self.tblDaily.horizontalHeaderItem(1)
        item.setText(_translate("frmProductReport", "Price"))
        item = self.tblDaily.horizontalHeaderItem(2)
        item.setText(_translate("frmProductReport", "Open"))
        item = self.tblDaily.horizontalHeaderItem(3)
        item.setText(_translate("frmProductReport", "Higher"))
        item = self.tblDaily.horizontalHeaderItem(4)
        item.setText(_translate("frmProductReport", "Lower"))
        item = self.tblDaily.horizontalHeaderItem(5)
        item.setText(_translate("frmProductReport", "Agrupation Start"))
        self.label_6.setText(_translate("frmProductReport", "Splits and dividends hasn\'t been adjusted in this prices. They are database prices"))
        self.tabHistorical.setTabText(self.tabHistorical.indexOf(self.tab_5), _translate("frmProductReport", "Daily prices "))
        item = self.tblWeekly.horizontalHeaderItem(0)
        item.setText(_translate("frmProductReport", "Date"))
        item = self.tblWeekly.horizontalHeaderItem(1)
        item.setText(_translate("frmProductReport", "Price"))
        item = self.tblWeekly.horizontalHeaderItem(2)
        item.setText(_translate("frmProductReport", "Open"))
        item = self.tblWeekly.horizontalHeaderItem(3)
        item.setText(_translate("frmProductReport", "Higher"))
        item = self.tblWeekly.horizontalHeaderItem(4)
        item.setText(_translate("frmProductReport", "Lower"))
        item = self.tblWeekly.horizontalHeaderItem(5)
        item.setText(_translate("frmProductReport", "Agrupation start"))
        self.label_8.setText(_translate("frmProductReport", "Splits and dividends hasn\'t been adjusted in this prices. They are database prices"))
        self.tabHistorical.setTabText(self.tabHistorical.indexOf(self.tab_14), _translate("frmProductReport", "Weekly prices"))
        item = self.tblMonthly.horizontalHeaderItem(0)
        item.setText(_translate("frmProductReport", "Date"))
        item = self.tblMonthly.horizontalHeaderItem(1)
        item.setText(_translate("frmProductReport", "Price"))
        item = self.tblMonthly.horizontalHeaderItem(2)
        item.setText(_translate("frmProductReport", "Open"))
        item = self.tblMonthly.horizontalHeaderItem(3)
        item.setText(_translate("frmProductReport", "Higher"))
        item = self.tblMonthly.horizontalHeaderItem(4)
        item.setText(_translate("frmProductReport", "Lower"))
        item = self.tblMonthly.horizontalHeaderItem(5)
        item.setText(_translate("frmProductReport", "Agrupation start"))
        self.label_17.setText(_translate("frmProductReport", "Splits and dividends hasn\'t been adjusted in this prices. They are database prices"))
        self.tabHistorical.setTabText(self.tabHistorical.indexOf(self.tab_3), _translate("frmProductReport", "Monthly prices"))
        item = self.tblYearly.horizontalHeaderItem(0)
        item.setText(_translate("frmProductReport", "Date"))
        item = self.tblYearly.horizontalHeaderItem(1)
        item.setText(_translate("frmProductReport", "Price"))
        item = self.tblYearly.horizontalHeaderItem(2)
        item.setText(_translate("frmProductReport", "Open"))
        item = self.tblYearly.horizontalHeaderItem(3)
        item.setText(_translate("frmProductReport", "Higher"))
        item = self.tblYearly.horizontalHeaderItem(4)
        item.setText(_translate("frmProductReport", "Lower"))
        item = self.tblYearly.horizontalHeaderItem(5)
        item.setText(_translate("frmProductReport", "Agrupation start"))
        self.label_18.setText(_translate("frmProductReport", "Splits and dividends hasn\'t been adjusted in this prices. They are database prices"))
        self.tabHistorical.setTabText(self.tabHistorical.indexOf(self.tab_13), _translate("frmProductReport", "Annual prices"))
        self.tblMensuales.setToolTip(_translate("frmProductReport", "Table has been calculted with the last price of the previous month and the last price of the corresponding month"))
        item = self.tblMensuales.horizontalHeaderItem(0)
        item.setText(_translate("frmProductReport", "Year"))
        item = self.tblMensuales.horizontalHeaderItem(1)
        item.setText(_translate("frmProductReport", "January"))
        item = self.tblMensuales.horizontalHeaderItem(2)
        item.setText(_translate("frmProductReport", "February"))
        item = self.tblMensuales.horizontalHeaderItem(3)
        item.setText(_translate("frmProductReport", "March"))
        item = self.tblMensuales.horizontalHeaderItem(4)
        item.setText(_translate("frmProductReport", "April"))
        item = self.tblMensuales.horizontalHeaderItem(5)
        item.setText(_translate("frmProductReport", "May"))
        item = self.tblMensuales.horizontalHeaderItem(6)
        item.setText(_translate("frmProductReport", "June"))
        item = self.tblMensuales.horizontalHeaderItem(7)
        item.setText(_translate("frmProductReport", "July"))
        item = self.tblMensuales.horizontalHeaderItem(8)
        item.setText(_translate("frmProductReport", "August"))
        item = self.tblMensuales.horizontalHeaderItem(9)
        item.setText(_translate("frmProductReport", "September"))
        item = self.tblMensuales.horizontalHeaderItem(10)
        item.setText(_translate("frmProductReport", "October"))
        item = self.tblMensuales.horizontalHeaderItem(11)
        item.setText(_translate("frmProductReport", "November"))
        item = self.tblMensuales.horizontalHeaderItem(12)
        item.setText(_translate("frmProductReport", "December"))
        item = self.tblMensuales.horizontalHeaderItem(13)
        item.setText(_translate("frmProductReport", "Total"))
        self.label_19.setText(_translate("frmProductReport", "These percentages have been calculated with prices with adjusted splits"))
        self.tabHistorical.setTabText(self.tabHistorical.indexOf(self.tab_6), _translate("frmProductReport", "Monthly returns"))
        self.tabHistorical.setTabText(self.tabHistorical.indexOf(self.tabSplits), _translate("frmProductReport", "Splits / Contrasplits"))
        self.tab.setTabText(self.tab.indexOf(self.tabQuotes), _translate("frmProductReport", "Historical prices"))
        self.tabEstimaciones.setTabText(self.tabEstimaciones.indexOf(self.tab_2), _translate("frmProductReport", "DPS Paid"))
        item = self.tblDividendsEstimations.horizontalHeaderItem(0)
        item.setText(_translate("frmProductReport", "Year"))
        item = self.tblDividendsEstimations.horizontalHeaderItem(1)
        item.setText(_translate("frmProductReport", "Price"))
        item = self.tblDividendsEstimations.horizontalHeaderItem(2)
        item.setText(_translate("frmProductReport", "%"))
        item = self.tblDividendsEstimations.horizontalHeaderItem(3)
        item.setText(_translate("frmProductReport", "Annotation date"))
        item = self.tblDividendsEstimations.horizontalHeaderItem(4)
        item.setText(_translate("frmProductReport", "Source"))
        item = self.tblDividendsEstimations.horizontalHeaderItem(5)
        item.setText(_translate("frmProductReport", "Manual"))
        self.tabEstimaciones.setTabText(self.tabEstimaciones.indexOf(self.tab_8), _translate("frmProductReport", "DPS Estimations"))
        item = self.tblEPS.horizontalHeaderItem(0)
        item.setText(_translate("frmProductReport", "Year"))
        item = self.tblEPS.horizontalHeaderItem(1)
        item.setText(_translate("frmProductReport", "Price"))
        item = self.tblEPS.horizontalHeaderItem(2)
        item.setText(_translate("frmProductReport", "PER"))
        item = self.tblEPS.horizontalHeaderItem(3)
        item.setText(_translate("frmProductReport", "Annotation date"))
        item = self.tblEPS.horizontalHeaderItem(4)
        item.setText(_translate("frmProductReport", "Source"))
        item = self.tblEPS.horizontalHeaderItem(5)
        item.setText(_translate("frmProductReport", "Manual"))
        self.tabEstimaciones.setTabText(self.tabEstimaciones.indexOf(self.tab_9), _translate("frmProductReport", "EPS Estimations"))
        self.tab.setTabText(self.tab.indexOf(self.tabOther), _translate("frmProductReport", "Other data"))
        self.actionQuoteNew.setText(_translate("frmProductReport", "New price"))
        self.actionQuoteNew.setToolTip(_translate("frmProductReport", "New price"))
        self.actionQuoteDelete.setText(_translate("frmProductReport", "Delete price from selected day"))
        self.actionQuoteDelete.setToolTip(_translate("frmProductReport", "Delete price from selected day"))
        self.actionEstimationDPSNew.setText(_translate("frmProductReport", "New dividend per share estimation"))
        self.actionEstimationDPSNew.setToolTip(_translate("frmProductReport", "New dividend per share estimation"))
        self.actionEstimationDPSDelete.setText(_translate("frmProductReport", "Remove dividend per share estimation"))
        self.actionEstimationDPSDelete.setToolTip(_translate("frmProductReport", "Remove dividend per share estimation"))
        self.actionPurgeDay.setText(_translate("frmProductReport", "Purge Day"))
        self.actionPurgeDay.setToolTip(_translate("frmProductReport", "Purge Day from innecesary quotes. Leaves high, low, open and close quotes"))
        self.actionQuoteEdit.setText(_translate("frmProductReport", "Edit Quote"))
        self.actionQuoteEdit.setToolTip(_translate("frmProductReport", "Edit Quote"))
        self.actionEstimationEPSNew.setText(_translate("frmProductReport", "New earnings per share estimation"))
        self.actionEstimationEPSNew.setToolTip(_translate("frmProductReport", "New earnings per share estimation"))
        self.actionEstimationEPSDelete.setText(_translate("frmProductReport", "Remove earnings per share estimation"))
        self.actionEstimationEPSDelete.setToolTip(_translate("frmProductReport", "Remove earnings per share estimation"))
        self.actionDPSNew.setText(_translate("frmProductReport", "New DPS"))
        self.actionDPSNew.setToolTip(_translate("frmProductReport", "New DPS"))
        self.actionDPSDelete.setText(_translate("frmProductReport", "Remove DPS"))
        self.actionDPSDelete.setToolTip(_translate("frmProductReport", "Remove DPS"))
        self.actionDividendXuNew.setText(_translate("frmProductReport", "Selected investment dividend"))
        self.actionDividendXuNew.setToolTip(_translate("frmProductReport", "Selected investment dividend"))
        self.actionQuoteDeleteDays.setText(_translate("frmProductReport", "Delete all prices from selected day"))
        self.actionQuoteDeleteDays.setToolTip(_translate("frmProductReport", "Delete all prices from selected day"))
        self.actionQuoteDeleteMonths.setText(_translate("frmProductReport", "Delete all prices from selected month"))
        self.actionQuoteDeleteMonths.setToolTip(_translate("frmProductReport", "Delete all prices from selected month"))
        self.actionQuoteDeleteYears.setText(_translate("frmProductReport", "Delete all prices from selected year"))
        self.actionQuoteDeleteYears.setToolTip(_translate("frmProductReport", "Delete all prices from selected year"))
        self.actionQuoteImport.setText(_translate("frmProductReport", "Import quotes from Libreoffice ODS"))
        self.actionQuoteImport.setToolTip(_translate("frmProductReport", "Needs a file with first sheet with two columns. Date/Datetime in ISO Format  and value"))
        self.actionSplitNew.setText(_translate("frmProductReport", "New Split / Contrasplit"))
        self.actionSplitNew.setToolTip(_translate("frmProductReport", "New Split / Contrasplit"))
        self.actionSplitRemove.setText(_translate("frmProductReport", "Remove Split / Contrasplit"))
        self.actionSplitRemove.setToolTip(_translate("frmProductReport", "Remove Split / Contrasplit"))
        self.actionSplitEdit.setText(_translate("frmProductReport", "Edit Split / Contrasplit"))
        self.actionSplitEdit.setToolTip(_translate("frmProductReport", "Edit Split / Contrasplit"))
        self.actionDPSImport.setText(_translate("frmProductReport", "Import dividend per share from Libreoffice ODS"))
        self.actionDPSImport.setToolTip(_translate("frmProductReport", "Needs a file with first sheet with two columns. Date/Datetime in ISO Format  and value"))
        self.actionQuoteExport.setText(_translate("frmProductReport", "Export quotes to Libreoffice ODS"))
        self.actionQuoteExport.setToolTip(_translate("frmProductReport", "Export quotes to Libreoffice ODS"))


from xulpymoney.ui.myqtablewidget import myQTableWidget
import xulpymoney.images.xulpymoney_rc
