from PyQt5.QtCore import QCoreApplication
QCoreApplication.translate('Core','Personal Management')
QCoreApplication.translate('Core','Cash')
QCoreApplication.translate('Core', 'Desconocido')
QCoreApplication.translate('Core', 'Inicio de Cuenta')
QCoreApplication.translate('Core', 'Supermercado')
QCoreApplication.translate('Core', 'Restaurante')
QCoreApplication.translate('Core', 'Transferencia. Origen')
QCoreApplication.translate('Core', 'Transferencia. Destino')
QCoreApplication.translate('Core', 'Impuestos. Devolución')
QCoreApplication.translate('Core', 'Gasolina')
QCoreApplication.translate('Core', 'Ocio')
QCoreApplication.translate('Core', 'Teléfono')
QCoreApplication.translate('Core', 'Nómina')
QCoreApplication.translate('Core', 'Televisión & Video & Cine')
QCoreApplication.translate('Core', 'Casa. Comunidad')
QCoreApplication.translate('Core', 'Universidad & Estudios')
QCoreApplication.translate('Core', 'Viajes (Billetes y autopistas)')
QCoreApplication.translate('Core', 'Hoteles')
QCoreApplication.translate('Core', 'Loterías')
QCoreApplication.translate('Core', 'Regalos')
QCoreApplication.translate('Core', 'Electricidad')
QCoreApplication.translate('Core', 'Gas')
QCoreApplication.translate('Core', 'Intereses Negativos')
QCoreApplication.translate('Core', 'Ropa')
QCoreApplication.translate('Core', 'Médicos ')
QCoreApplication.translate('Core', 'Intereses Positivos')
QCoreApplication.translate('Core', 'Loterías Premios')
QCoreApplication.translate('Core', 'Informática')
QCoreApplication.translate('Core', 'Coche')
QCoreApplication.translate('Core', 'Herencia')
QCoreApplication.translate('Core', 'Compra producto de inversión')
QCoreApplication.translate('Core', 'Pagas')
QCoreApplication.translate('Core', 'Invitaciones')
QCoreApplication.translate('Core', 'Otros Ingresos')
QCoreApplication.translate('Core', 'Casa. Compra')
QCoreApplication.translate('Core', 'Venta producto de inversión')
QCoreApplication.translate('Core', 'Casa. Infraestructura')
QCoreApplication.translate('Core', 'Impuestos. Pago')
QCoreApplication.translate('Core', 'Comisiones bancarias')
QCoreApplication.translate('Core', 'Dividendos')
QCoreApplication.translate('Core', 'Facturacion Tarjeta')
QCoreApplication.translate('Core', 'Añadido de acciones')
QCoreApplication.translate('Core', 'Ajustes negativos')
QCoreApplication.translate('Core', 'Casa. Compra pareja')
QCoreApplication.translate('Core', 'Préstamo (Me devuelven)')
QCoreApplication.translate('Core', 'Seguro')
QCoreApplication.translate('Core', 'Boda')
QCoreApplication.translate('Core', 'Regalos económicos recibidos')
QCoreApplication.translate('Core', 'Prima asistencia')
QCoreApplication.translate('Core', 'Otros Ingresos Pareja')
QCoreApplication.translate('Core', 'Casa. Asistenta')
QCoreApplication.translate('Core', 'Taxi')
QCoreApplication.translate('Core', 'Copas')
QCoreApplication.translate('Core', 'Gimnasio')
QCoreApplication.translate('Core', 'Divorcio')
QCoreApplication.translate('Core', 'Donaciones')
QCoreApplication.translate('Core', 'Garage')
QCoreApplication.translate('Core', 'Comisión de custodia de valores')
QCoreApplication.translate('Core', 'Casa. Alquiler')
QCoreApplication.translate('Core', 'Dividendos. Venta derechos')
QCoreApplication.translate('Core', 'Renta fija. Pago cupón corrido')
QCoreApplication.translate('Core', 'Pareja. Apoyo')
QCoreApplication.translate('Core', 'Renta fija. Cobro cupón corrido')
QCoreApplication.translate('Core', 'Renta fija. Pago cupón')
QCoreApplication.translate('Core', 'Credit card refund')
QCoreApplication.translate('Core', 'HL adjustment income')
QCoreApplication.translate('Core', 'HL adjustment expense')
QCoreApplication.translate('Core', 'HL Guarantee payment')
QCoreApplication.translate('Core', 'HL Guarantee return')
QCoreApplication.translate('Core', 'HL Operation commission')
QCoreApplication.translate('Core', 'HL Paid interest')
QCoreApplication.translate('Core', 'HL Received interest')
QCoreApplication.translate('Core', 'Rollover Paid')
QCoreApplication.translate('Core', 'Rollover Received')
